@@ -18,6 +18,9 @@ import models as mymodels
 from django.conf import settings as conf
 from django.views.generic import DetailView, ListView
 
+from rest_framework.generics import (ListCreateAPIView,
+                                     RetrieveUpdateDestroyAPIView)
+
 from rtimes import worktime, humanize_time, humanize_time_day, date_range
 
 
@@ -99,3 +102,13 @@ class Refresh(ListView):
     def get_template_names(self):
         if self.request.is_ajax():
             return ['rstamper/stamp_tabs.html']
+
+
+class CustomersApi(ListCreateAPIView):
+
+    model = mymodels.Customer
+
+
+class StampsApi(ListCreateAPIView):
+
+    model = mymodels.Stamp
\ No newline at end of file
